@@ -143,6 +143,10 @@ class DependencyTree(Tree):
         including objects that may depend on certain Datasets being generated.
         This includes readers, compositors, and modifiers.
 
+        Composites and modifiers are defined per-sensor. If multiple sensors
+        are available, compositors and modifiers are searched for in
+        sensor alphabetical order.
+
         Args:
             readers (dict): Reader name -> Reader Object
             compositors (dict): Sensor name -> Composite ID -> Composite Object
@@ -441,7 +445,7 @@ class DependencyTree(Tree):
 
     def get_compositor(self, key):
         """Get a compositor."""
-        for sensor_name in self.compositors.keys():
+        for sensor_name in sorted(self.compositors):
             try:
                 return self.compositors[sensor_name][key]
             except KeyError:
@@ -453,7 +457,7 @@ class DependencyTree(Tree):
         """Get a modifer."""
         # create a DataID for the compositor we are generating
         modifier = comp_id['modifiers'][-1]
-        for sensor_name in self.modifiers.keys():
+        for sensor_name in sorted(self.modifiers):
             modifiers = self.modifiers[sensor_name]
             compositors = self.compositors[sensor_name]
             if modifier not in modifiers:
