@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License along with
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
-"""Advanced Geostationary Radiation Imager reader for the Level_1 HDF format
+"""Advanced Geostationary Radiation Imager reader for the Level_1 HDF format.
 
 The files read by this reader are described in the official Real Time Data Service:
 
@@ -46,15 +46,17 @@ PLATFORM_NAMES = {'FY4A': 'FY-4A',
 
 
 class HDF_AGRI_L1(HDF5FileHandler):
+    """AGRI l1 file handler."""
 
     def __init__(self, filename, filename_info, filetype_info):
+        """Init filehandler."""
         super(HDF_AGRI_L1, self).__init__(filename, filename_info, filetype_info)
 
     def get_dataset(self, dataset_id, ds_info):
         """Load a dataset."""
-        logger.debug('Reading in get_dataset %s.', dataset_id.name)
-        file_key = ds_info.get('file_key', dataset_id.name)
-        lut_key = ds_info.get('lut_key', dataset_id.name)
+        logger.debug('Reading in get_dataset %s.', dataset_id['name'])
+        file_key = ds_info.get('file_key', dataset_id['name'])
+        lut_key = ds_info.get('lut_key', dataset_id['name'])
         data = self.get(file_key)
         lut = self.get(lut_key)
         if data.ndim >= 2:
@@ -105,9 +107,9 @@ class HDF_AGRI_L1(HDF5FileHandler):
         data.attrs.update({'platform_name': satname,
                            'sensor': self['/attr/Sensor Identification Code'].lower(),
                            'orbital_parameters': {
-                               'satellite_nominal_latitude': self['/attr/NOMCenterLat'],
-                               'satellite_nominal_longitude': self['/attr/NOMCenterLon'],
-                               'satellite_nominal_altitude': self['/attr/NOMSatHeight']}})
+                               'satellite_nominal_latitude': self['/attr/NOMCenterLat'].item(),
+                               'satellite_nominal_longitude': self['/attr/NOMCenterLon'].item(),
+                               'satellite_nominal_altitude': self['/attr/NOMSatHeight'].item()}})
         data.attrs.update(ds_info)
 
         # remove attributes that could be confusing later
@@ -121,9 +123,10 @@ class HDF_AGRI_L1(HDF5FileHandler):
         return data
 
     def get_area_def(self, key):
+        """Get the area definition."""
         # Coordination Group for Meteorological Satellites LRIT/HRIT Global Specification
         # https://www.cgms-info.org/documents/cgms-lrit-hrit-global-specification-(v2-8-of-30-oct-2013).pdf
-        res = key.resolution
+        res = key['resolution']
         pdict = {}
         pdict['coff'] = _COFF_list[_resolution_list.index(res)]
         pdict['loff'] = _LOFF_list[_resolution_list.index(res)]
@@ -145,13 +148,13 @@ class HDF_AGRI_L1(HDF5FileHandler):
 
         pdict['a_desc'] = "AGRI {} area".format(self.filename_info['observation_type'])
 
-        if (key.name in b500):
+        if (key['name'] in b500):
             pdict['a_name'] = self.filename_info['observation_type']+'_500m'
             pdict['p_id'] = 'FY-4A, 500m'
-        elif (key.name in b1000):
+        elif (key['name'] in b1000):
             pdict['a_name'] = self.filename_info['observation_type']+'_1000m'
             pdict['p_id'] = 'FY-4A, 1000m'
-        elif (key.name in b2000):
+        elif (key['name'] in b2000):
             pdict['a_name'] = self.filename_info['observation_type']+'_2000m'
             pdict['p_id'] = 'FY-4A, 2000m'
         else:
@@ -172,7 +175,7 @@ class HDF_AGRI_L1(HDF5FileHandler):
         return area
 
     def dn2(self, dn, calibration, slope, offset):
-        """Convert digital number (DN) to reflectance or radiance
+        """Convert digital number (DN) to reflectance or radiance.
 
         Args:
             dn: Raw detector digital number
@@ -196,7 +199,8 @@ class HDF_AGRI_L1(HDF5FileHandler):
         return lut[block]
 
     def calibrate(self, data, lut):
-        """Calibrate digital number (DN) to brightness_temperature
+        """Calibrate digital number (DN) to brightness_temperature.
+
         Args:
             dn: Raw detector digital number
             lut: the look up table
@@ -214,10 +218,12 @@ class HDF_AGRI_L1(HDF5FileHandler):
 
     @property
     def start_time(self):
+        """Get the start time."""
         start_time = self['/attr/Observing Beginning Date'] + 'T' + self['/attr/Observing Beginning Time'] + 'Z'
         return datetime.strptime(start_time, '%Y-%m-%dT%H:%M:%S.%fZ')
 
     @property
     def end_time(self):
+        """Get the end time."""
         end_time = self['/attr/Observing Ending Date'] + 'T' + self['/attr/Observing Ending Time'] + 'Z'
         return datetime.strptime(end_time, '%Y-%m-%dT%H:%M:%S.%fZ')
