@@ -17,9 +17,28 @@
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """SEVIRI netcdf format reader.
 
+Notes:
+    When loading solar channels, this reader applies a correction for the
+    Sun-Earth distance variation throughout the year - as recommended by
+    the EUMETSAT document:
+        'Conversion from radiances to reflectances for SEVIRI warm channels'
+    In the unlikely situation that this correction is not required, it can be
+    removed on a per-channel basis using the
+    satpy.readers.utils.remove_earthsun_distance_correction(channel, utc_time)
+    function.
+
 References:
-    MSG Level 1.5 Image Data Format Description
-    https://www.eumetsat.int/website/wcm/idc/idcplg?IdcService=GET_FILE&dDocName=PDF_TEN_05105_MSG_IMG_DATA&RevisionSelectionMethod=LatestReleased&Rendition=Web
+
+    - `MSG Level 1.5 Image Data Format Description`_
+    - `Conversion from radiances to reflectances for SEVIRI warm channels`_
+
+.. _MSG Level 1.5 Image Data Format Description:
+    https://www.eumetsat.int/website/wcm/idc/idcplg?IdcService=GET_FILE&dDocName=PDF_TEN_05105_MSG_IMG_DATA&
+    RevisionSelectionMethod=LatestReleased&Rendition=Web
+
+.. _Conversion from radiances to reflectances for SEVIRI warm channels:
+    https://www.eumetsat.int/website/wcm/idc/idcplg?IdcService=GET_FILE&dDocName=PDF_MSG_SEVIRI_RAD2REFL&
+    RevisionSelectionMethod=LatestReleased&Rendition=Web
 """
 
 from satpy.readers.file_handlers import BaseFileHandler
@@ -34,7 +53,10 @@ import datetime
 
 
 class NCSEVIRIFileHandler(BaseFileHandler, SEVIRICalibrationHandler):
+    """File handler for NC seviri files."""
+
     def __init__(self, filename, filename_info, filetype_info):
+        """Init the file handler."""
         super(NCSEVIRIFileHandler, self).__init__(filename, filename_info, filetype_info)
         self.nc = None
         self.mda = {}
@@ -43,13 +65,16 @@ class NCSEVIRIFileHandler(BaseFileHandler, SEVIRICalibrationHandler):
 
     @property
     def start_time(self):
+        """Get the start time."""
         return self.deltaSt
 
     @property
     def end_time(self):
+        """Get the end time."""
         return self.deltaEnd
 
     def _read_file(self):
+        """Read the file."""
         if self.nc is None:
 
             self.nc = xr.open_dataset(self.filename,
@@ -86,8 +111,8 @@ class NCSEVIRIFileHandler(BaseFileHandler, SEVIRICalibrationHandler):
         self.south = int(self.nc.attrs['south_most_line'])
 
     def get_dataset(self, dataset_id, dataset_info):
-
-        channel = dataset_id.name
+        """Get the dataset."""
+        channel = dataset_id['name']
         i = list(CHANNEL_NAMES.values()).index(channel)
 
         if (channel == 'HRV'):
@@ -115,18 +140,18 @@ class NCSEVIRIFileHandler(BaseFileHandler, SEVIRICalibrationHandler):
         # Correct for the scan line order
         dataset = dataset.sel(y=slice(None, None, -1))
 
-        if dataset_id.calibration == 'counts':
+        if dataset_id['calibration'] == 'counts':
             dataset.attrs['_FillValue'] = 0
 
-        if dataset_id.calibration in ['radiance', 'reflectance', 'brightness_temperature']:
+        if dataset_id['calibration'] in ['radiance', 'reflectance', 'brightness_temperature']:
             dataset = dataset.where(dataset != 0).astype('float32')
             dataset = self._convert_to_radiance(dataset, gain, offset)
 
-        if dataset_id.calibration == 'reflectance':
+        if dataset_id['calibration'] == 'reflectance':
             solar_irradiance = CALIB[int(self.platform_id)][channel]["F"]
             dataset = self._vis_calibrate(dataset, solar_irradiance)
 
-        elif dataset_id.calibration == 'brightness_temperature':
+        elif dataset_id['calibration'] == 'brightness_temperature':
             dataset = self._ir_calibrate(dataset, channel, cal_type)
 
         dataset.attrs.update(self.nc[dataset_info['nc_key']].attrs)
@@ -146,14 +171,14 @@ class NCSEVIRIFileHandler(BaseFileHandler, SEVIRICalibrationHandler):
         return dataset
 
     def get_area_def(self, dataset_id):
-
+        """Get the area def."""
         pdict = {}
         pdict['a'] = self.mda['projection_parameters']['a']
         pdict['b'] = self.mda['projection_parameters']['b']
         pdict['h'] = self.mda['projection_parameters']['h']
         pdict['ssp_lon'] = self.mda['projection_parameters']['ssp_longitude']
 
-        if dataset_id.name == 'HRV':
+        if dataset_id['name'] == 'HRV':
             pdict['nlines'] = self.mda['hrv_number_of_lines']
             pdict['ncols'] = self.mda['hrv_number_of_columns']
             pdict['a_name'] = 'geosmsg_hrv'
@@ -171,7 +196,7 @@ class NCSEVIRIFileHandler(BaseFileHandler, SEVIRICalibrationHandler):
         return area
 
     def get_area_extent(self, dsid):
-
+        """Get the area extent."""
         # following calculations assume grid origin is south-east corner
         # section 7.2.4 of MSG Level 1.5 Image Data Format Description
         origins = {0: 'NW', 1: 'SW', 2: 'SE', 3: 'NE'}
@@ -214,4 +239,6 @@ class NCSEVIRIFileHandler(BaseFileHandler, SEVIRICalibrationHandler):
 
 
 class NCSEVIRIHRVFileHandler(BaseFileHandler, SEVIRICalibrationHandler):
+    """HRV filehandler."""
+
     pass
