@@ -17,19 +17,13 @@
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """Geostationary project utility module tests package."""
 
-import sys
-
+import unittest
 from satpy.readers._geos_area import (get_xy_from_linecol,
                                       get_area_extent,
                                       get_area_definition)
 
 import numpy as np
 
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
-
 
 class TestGEOSProjectionUtil(unittest.TestCase):
     """Tests for the area utilities."""
@@ -138,6 +132,7 @@ class TestGEOSProjectionUtil(unittest.TestCase):
 
     def test_get_area_definition(self):
         """Test the retrieval of the area definition."""
+        from pyresample.utils import proj4_radius_parameters
         pdict, extent = self.make_pdict_ext(1, 'N2S')
         good_res = (-3000.4032785810186, -3000.4032785810186)
 
@@ -146,19 +141,7 @@ class TestGEOSProjectionUtil(unittest.TestCase):
         self.assertEqual(a_def.resolution, good_res)
         self.assertEqual(a_def.proj_dict['proj'], 'geos')
         self.assertEqual(a_def.proj_dict['units'], 'm')
-        self.assertEqual(a_def.proj_dict['a'], 6378169)
-        self.assertEqual(a_def.proj_dict['b'], 6356583.8)
+        a, b = proj4_radius_parameters(a_def.proj_dict)
+        self.assertEqual(a, 6378169)
+        self.assertEqual(b, 6356583.8)
         self.assertEqual(a_def.proj_dict['h'], 35785831)
-
-
-def suite():
-    """The test suite for test_geos_area."""
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestGEOSProjectionUtil))
-    return mysuite
-
-
-if __name__ == "__main__":
-    # So you can run tests from this module individually.
-    unittest.main()
