@@ -464,12 +464,10 @@ class TestBilinearResampler(unittest.TestCase):
     """Test the bilinear resampler."""
 
     @mock.patch('satpy.resample._move_existing_caches')
-    @mock.patch('satpy.resample.xr.Dataset')
-    @mock.patch('satpy.resample.zarr.open')
     @mock.patch('satpy.resample.BilinearResampler._create_cache_filename')
-    @mock.patch('pyresample.bilinear.xarr.XArrayResamplerBilinear')
-    def test_bil_resampling(self, resampler, create_filename, zarr_open,
-                            xr_dset, move_existing_caches):
+    @mock.patch('pyresample.bilinear.XArrayBilinearResampler')
+    def test_bil_resampling(self, xr_resampler, create_filename,
+                            move_existing_caches):
         """Test the bilinear resampler."""
         import numpy as np
         import dask.array as da
@@ -477,21 +475,13 @@ class TestBilinearResampler(unittest.TestCase):
         from satpy.resample import BilinearResampler
         data, source_area, swath_data, source_swath, target_area = get_test_data()
 
-        mock_dset = mock.MagicMock()
-        xr_dset.return_value = mock_dset
-
-        # Test that bilinear resampling info calculation is called,
-        # and the info is saved
-        zarr_open.side_effect = IOError()
+        # Test that bilinear resampling info calculation is called
         resampler = BilinearResampler(source_swath, target_area)
         resampler.precompute(
             mask=da.arange(5, chunks=5).astype(np.bool))
-        resampler.resampler.get_bil_info.assert_called()
-        resampler.resampler.get_bil_info.assert_called_with()
-        self.assertFalse(len(mock_dset.to_zarr.mock_calls), 1)
+        resampler.resampler.load_resampling_info.assert_not_called()
+        resampler.resampler.get_bil_info.assert_called_once()
         resampler.resampler.reset_mock()
-        zarr_open.reset_mock()
-        zarr_open.side_effect = None
 
         # Test that get_sample_from_bil_info is called properly
         fill_value = 8
@@ -514,60 +504,34 @@ class TestBilinearResampler(unittest.TestCase):
         # Test that the resampling info is tried to read from the disk
         resampler = BilinearResampler(source_swath, target_area)
         resampler.precompute(cache_dir='.')
-        zarr_open.assert_called()
+        resampler.resampler.load_resampling_info.assert_called()
 
         # Test caching the resampling info
         try:
             the_dir = tempfile.mkdtemp()
             resampler = BilinearResampler(source_area, target_area)
             create_filename.return_value = os.path.join(the_dir, 'test_cache.zarr')
-            zarr_open.reset_mock()
-            zarr_open.side_effect = IOError()
+            xr_resampler.return_value.load_resampling_info.side_effect = IOError
 
             resampler.precompute(cache_dir=the_dir)
-            xr_dset.assert_called()
+            resampler.resampler.save_resampling_info.assert_called()
             # assert data was saved to the on-disk cache
-            self.assertEqual(len(mock_dset.to_zarr.mock_calls), 1)
-            # assert that zarr.open was called to try to load
-            # something from disk
-            self.assertEqual(len(zarr_open.mock_calls), 1)
+            resampler.resampler.save_resampling_info.assert_called_once()
 
-            nbcalls = len(resampler.resampler.get_bil_info.mock_calls)
-            # test reusing the resampler
-            zarr_open.side_effect = None
+            nbcalls = resampler.resampler.get_bil_info.call_count
+            resampler.resampler.load_resampling_info.side_effect = None
 
-            class FakeZarr(dict):
-
-                def close(self):
-                    pass
-
-                def astype(self, dtype):
-                    return self
-
-                def compute(self):
-                    return self
-
-            zarr_open.return_value = FakeZarr(bilinear_s=1,
-                                              bilinear_t=2,
-                                              slices_x=3,
-                                              slices_y=4,
-                                              mask_slices=5,
-                                              out_coords_x=6,
-                                              out_coords_y=7)
             resampler.precompute(cache_dir=the_dir)
             # we already have things cached in-memory, no need to save again
-            self.assertEqual(len(mock_dset.to_zarr.mock_calls), 1)
+            resampler.resampler.save_resampling_info.assert_called_once()
             # we already have things cached in-memory, don't need to load
-            # self.assertEqual(len(zarr_open.mock_calls), 1)
-            self.assertEqual(len(resampler.resampler.get_bil_info.mock_calls), nbcalls)
+            self.assertEqual(resampler.resampler.get_bil_info.call_count, nbcalls)
 
             # test loading saved resampler
             resampler = BilinearResampler(source_area, target_area)
             resampler.precompute(cache_dir=the_dir)
-            self.assertEqual(len(zarr_open.mock_calls), 2)
-            self.assertEqual(len(resampler.resampler.get_bil_info.mock_calls), nbcalls)
-            # we should have cached things in-memory now
-            # self.assertEqual(len(resampler._index_caches), 1)
+            self.assertEqual(resampler.resampler.load_resampling_info.call_count, 3)
+            self.assertEqual(resampler.resampler.get_bil_info.call_count, nbcalls)
 
             resampler = BilinearResampler(source_area, target_area)
             resampler.precompute(cache_dir=the_dir)
