@@ -17,9 +17,27 @@
 """Utilities for various satpy tests."""
 
 from datetime import datetime
-from satpy.readers.yaml_reader import FileYAMLReader
 from unittest import mock
 
+from satpy.dataset import DataID, DataQuery
+from satpy.dataset.dataid import default_id_keys_config, minimal_default_keys_config
+from satpy.readers.yaml_reader import FileYAMLReader
+
+
+def make_dataid(**items):
+    """Make a DataID with default keys."""
+    return DataID(default_id_keys_config, **items)
+
+
+def make_cid(**items):
+    """Make a DataID with a minimal set of keys to id composites."""
+    return DataID(minimal_default_keys_config, **items)
+
+
+def make_dsq(**items):
+    """Make a dataset query."""
+    return DataQuery(**items)
+
 
 def spy_decorator(method_to_decorate):
     """Fancy decorate to wrap an object while still calling it.
@@ -87,25 +105,27 @@ def convert_file_content_to_data_array(file_content, attrs=tuple(),
 
 def test_datasets():
     """Get list of various test datasets."""
-    from satpy import DatasetID
     d = [
-        DatasetID(name='ds1'),
-        DatasetID(name='ds2'),
-        DatasetID(name='ds3'),
-        DatasetID(name='ds4', calibration='reflectance'),
-        DatasetID(name='ds4', calibration='radiance'),
-        DatasetID(name='ds5', resolution=250),
-        DatasetID(name='ds5', resolution=500),
-        DatasetID(name='ds5', resolution=1000),
-        DatasetID(name='ds6', wavelength=(0.1, 0.2, 0.3)),
-        DatasetID(name='ds7', wavelength=(0.4, 0.5, 0.6)),
-        DatasetID(name='ds8', wavelength=(0.7, 0.8, 0.9)),
-        DatasetID(name='ds9_fail_load', wavelength=(1.0, 1.1, 1.2)),
-        DatasetID(name='ds10', wavelength=(0.75, 0.85, 0.95)),
-        DatasetID(name='ds11', resolution=500),
-        DatasetID(name='ds11', resolution=1000),
-        DatasetID(name='ds12', resolution=500),
-        DatasetID(name='ds12', resolution=1000),
+        make_dataid(name='ds1', resolution=250, calibration='reflectance'),
+        make_dataid(name='ds2', resolution=250, calibration='reflectance'),
+        make_dataid(name='ds3'),
+        make_dataid(name='ds4', calibration='reflectance'),
+        make_dataid(name='ds4', calibration='radiance'),
+        make_dataid(name='ds5', resolution=250),
+        make_dataid(name='ds5', resolution=500),
+        make_dataid(name='ds5', resolution=1000),
+        make_dataid(name='ds6', wavelength=(0.1, 0.2, 0.3), resolution=250, calibration='reflectance'),
+        make_dataid(name='ds7', wavelength=(0.4, 0.5, 0.6)),
+        make_dataid(name='ds8', wavelength=(0.7, 0.8, 0.9)),
+        make_dataid(name='ds9_fail_load', wavelength=(1.0, 1.1, 1.2)),
+        make_dataid(name='ds10', wavelength=(0.75, 0.85, 0.95)),
+        make_dataid(name='ds11', resolution=500),
+        make_dataid(name='ds11', resolution=1000),
+        make_dataid(name='ds12', resolution=500),
+        make_dataid(name='ds12', resolution=1000),
+        make_dataid(name='B02', wavelength=(30.49, 30.51, 30.53), resolution=1000),
+        make_dataid(name='B03', wavelength=(30.62, 30.64, 30.66), resolution=500),
+        make_dataid(name='B04', wavelength=(30.83, 30.85, 30.87), resolution=1000),
     ]
     return d
 
@@ -125,10 +145,10 @@ def _create_fake_compositor(ds_id, prereqs, opt_prereqs):
     se = mock.MagicMock()
 
     def _se(datasets, optional_datasets=None, ds_id=ds_id, **kwargs):
-        if ds_id.name == 'comp14':
+        if ds_id['name'] == 'comp14':
             # used as a test when composites update the dataset id with
             # information from prereqs
-            ds_id = ds_id._replace(resolution=555)
+            ds_id = DataID(ds_id.id_keys, resolution=555, **ds_id)
         if len(datasets) != len(prereqs):
             raise ValueError("Not enough prerequisite datasets passed")
         return DataArray(data=np.arange(75).reshape(5, 5, 3),
@@ -144,7 +164,6 @@ def _create_fake_modifiers(name, prereqs, opt_prereqs):
     import numpy as np
     from xarray import DataArray
     from satpy.composites import CompositeBase, IncompatibleAreas
-    from satpy import DatasetID
 
     attrs = {
         'name': name,
@@ -165,7 +184,7 @@ def _create_fake_modifiers(name, prereqs, opt_prereqs):
                             continue
                         assert optional_datasets is not None and \
                             len(optional_datasets)
-                resolution = DatasetID.from_dict(datasets[0].attrs).resolution
+                resolution = datasets[0].attrs.get('resolution')
                 if name == 'res_change' and resolution is not None:
                     i = datasets[0].attrs.copy()
                     i['resolution'] *= 5
@@ -189,48 +208,50 @@ def _create_fake_modifiers(name, prereqs, opt_prereqs):
 
 def test_composites(sensor_name):
     """Create some test composites."""
-    from satpy import DatasetID, DatasetDict
+    from satpy import DatasetDict
     # Composite ID -> (prereqs, optional_prereqs)
     comps = {
-        DatasetID(name='comp1'): (['ds1'], []),
-        DatasetID(name='comp2'): (['ds1', 'ds2'], []),
-        DatasetID(name='comp3'): (['ds1', 'ds2', 'ds3'], []),
-        DatasetID(name='comp4'): (['comp2', 'ds3'], []),
-        DatasetID(name='comp5'): (['ds1', 'ds2'], ['ds3']),
-        DatasetID(name='comp6'): (['ds1', 'ds2'], ['comp2']),
-        DatasetID(name='comp7'): (['ds1', 'comp2'], ['ds2']),
-        DatasetID(name='comp8'): (['ds_NOPE', 'comp2'], []),
-        DatasetID(name='comp9'): (['ds1', 'comp2'], ['ds_NOPE']),
-        DatasetID(name='comp10'): ([DatasetID('ds1', modifiers=('mod1',)), 'comp2'], []),
-        DatasetID(name='comp11'): ([0.22, 0.48, 0.85], []),
-        DatasetID(name='comp12'): ([DatasetID(wavelength=0.22, modifiers=('mod1',)),
-                                    DatasetID(wavelength=0.48, modifiers=('mod1',)),
-                                    DatasetID(wavelength=0.85, modifiers=('mod1',))], []),
-        DatasetID(name='comp13'): ([DatasetID(name='ds5', modifiers=('res_change',))], []),
-        DatasetID(name='comp14'): (['ds1'], []),
-        DatasetID(name='comp15'): (['ds1', 'ds9_fail_load'], []),
-        DatasetID(name='comp16'): (['ds1'], ['ds9_fail_load']),
-        DatasetID(name='comp17'): (['ds1', 'comp15'], []),
-        DatasetID(name='comp18'): (['ds3',
-                                    DatasetID(name='ds4', modifiers=('mod1', 'mod3',)),
-                                    DatasetID(name='ds5', modifiers=('mod1', 'incomp_areas'))], []),
-        DatasetID(name='comp18_2'): (['ds3',
-                                      DatasetID(name='ds4', modifiers=('mod1', 'mod3',)),
-                                      DatasetID(name='ds5', modifiers=('mod1', 'incomp_areas_opt'))], []),
-        DatasetID(name='comp19'): ([DatasetID('ds5', modifiers=('res_change',)), 'comp13', 'ds2'], []),
-        DatasetID(name='comp20'): ([DatasetID(name='ds5', modifiers=('mod_opt_prereq',))], []),
-        DatasetID(name='comp21'): ([DatasetID(name='ds5', modifiers=('mod_bad_opt',))], []),
-        DatasetID(name='comp22'): ([DatasetID(name='ds5', modifiers=('mod_opt_only',))], []),
-        DatasetID(name='comp23'): ([0.8], []),
-        DatasetID(name='static_image'): ([], []),
-        DatasetID(name='comp24', resolution=500): ([DatasetID(name='ds11', resolution=500),
-                                                    DatasetID(name='ds12', resolution=500)], []),
-        DatasetID(name='comp24', resolution=1000): ([DatasetID(name='ds11', resolution=1000),
-                                                     DatasetID(name='ds12', resolution=1000)], []),
-        DatasetID(name='comp25', resolution=500): ([DatasetID(name='comp24', resolution=500),
-                                                    DatasetID(name='ds5', resolution=500)], []),
-        DatasetID(name='comp25', resolution=1000): ([DatasetID(name='comp24', resolution=1000),
-                                                     DatasetID(name='ds5', resolution=1000)], []),
+        make_cid(name='comp1'): (['ds1'], []),
+        make_cid(name='comp2'): (['ds1', 'ds2'], []),
+        make_cid(name='comp3'): (['ds1', 'ds2', 'ds3'], []),
+        make_cid(name='comp4'): (['comp2', 'ds3'], []),
+        make_cid(name='comp5'): (['ds1', 'ds2'], ['ds3']),
+        make_cid(name='comp6'): (['ds1', 'ds2'], ['comp2']),
+        make_cid(name='comp7'): (['ds1', 'comp2'], ['ds2']),
+        make_cid(name='comp8'): (['ds_NOPE', 'comp2'], []),
+        make_cid(name='comp9'): (['ds1', 'comp2'], ['ds_NOPE']),
+        make_cid(name='comp10'): ([make_dsq(name='ds1', modifiers=('mod1',)), 'comp2'], []),
+        make_cid(name='comp11'): ([0.22, 0.48, 0.85], []),
+        make_cid(name='comp12'): ([make_dsq(wavelength=0.22, modifiers=('mod1',)),
+                                   make_dsq(wavelength=0.48, modifiers=('mod1',)),
+                                   make_dsq(wavelength=0.85, modifiers=('mod1',))], []),
+        make_cid(name='comp13'): ([make_dsq(name='ds5', modifiers=('res_change',))], []),
+        make_cid(name='comp14'): (['ds1'], []),
+        make_cid(name='comp15'): (['ds1', 'ds9_fail_load'], []),
+        make_cid(name='comp16'): (['ds1'], ['ds9_fail_load']),
+        make_cid(name='comp17'): (['ds1', 'comp15'], []),
+        make_cid(name='comp18'): (['ds3',
+                                   make_dsq(name='ds4', modifiers=('mod1', 'mod3',)),
+                                   make_dsq(name='ds5', modifiers=('mod1', 'incomp_areas'))], []),
+        make_cid(name='comp18_2'): (['ds3',
+                                     make_dsq(name='ds4', modifiers=('mod1', 'mod3',)),
+                                     make_dsq(name='ds5', modifiers=('mod1', 'incomp_areas_opt'))], []),
+        make_cid(name='comp19'): ([make_dsq(name='ds5', modifiers=('res_change',)), 'comp13', 'ds2'], []),
+        make_cid(name='comp20'): ([make_dsq(name='ds5', modifiers=('mod_opt_prereq',))], []),
+        make_cid(name='comp21'): ([make_dsq(name='ds5', modifiers=('mod_bad_opt',))], []),
+        make_cid(name='comp22'): ([make_dsq(name='ds5', modifiers=('mod_opt_only',))], []),
+        make_cid(name='comp23'): ([0.8], []),
+        make_cid(name='static_image'): ([], []),
+        make_cid(name='comp24', resolution=500): ([make_dsq(name='ds11', resolution=500),
+                                                   make_dsq(name='ds12', resolution=500)], []),
+        make_cid(name='comp24', resolution=1000): ([make_dsq(name='ds11', resolution=1000),
+                                                    make_dsq(name='ds12', resolution=1000)], []),
+        make_cid(name='comp25', resolution=500): ([make_dsq(name='comp24', resolution=500),
+                                                   make_dsq(name='ds5', resolution=500)], []),
+        make_cid(name='comp25', resolution=1000): ([make_dsq(name='comp24', resolution=1000),
+                                                    make_dsq(name='ds5', resolution=1000)], []),
+        make_cid(name='ahi_green'): ([make_dsq(wavelength=30.5, modifiers=('sunz_corr', 'rayleigh_corr')),
+                                      make_dsq(wavelength=30.85, modifiers=('sunz_corr',))], [])
     }
     # Modifier name -> (prereqs (not including to-be-modified), opt_prereqs)
     mods = {
@@ -239,13 +260,14 @@ def test_composites(sensor_name):
         'mod3': (['ds2'], []),
         'res_change': ([], []),
         'incomp_areas': (['ds1'], []),
-        'incomp_areas_opt': ([DatasetID(name='ds1', modifiers=('incomp_areas',))], ['ds2']),
+        'incomp_areas_opt': ([make_dataid(name='ds1', modifiers=('incomp_areas',))], ['ds2']),
         'mod_opt_prereq': (['ds1'], ['ds2']),
         'mod_bad_opt': (['ds1'], ['ds9_fail_load']),
         'mod_opt_only': ([], ['ds2']),
-        'mod_wl': ([DatasetID(wavelength=0.2, modifiers=('mod1',))], []),
+        'mod_wl': ([make_dsq(wavelength=0.2, modifiers=('mod1',))], []),
+        'sunz_corr': ([], ['sunz_angles_NOPE']),
+        'rayleigh_corr': ([make_dsq(wavelength=30.64, modifiers=('sunz_corr',))], [])
     }
-
     comps = {sensor_name: DatasetDict((k, _create_fake_compositor(k, *v)) for k, v in comps.items())}
     mods = {sensor_name: dict((k, _create_fake_modifiers(k, *v)) for k, v in mods.items())}
 
@@ -253,13 +275,13 @@ def test_composites(sensor_name):
 
 
 def _filter_datasets(all_ds, names_or_ids):
-    """Help filtering DatasetIDs by name or DatasetID."""
-    # DatasetID will match a str to the name
+    """Help filtering DataIDs by name or DataQuery."""
+    # DataID will match a str to the name
     # need to separate them out
     str_filter = [ds_name for ds_name in names_or_ids if isinstance(ds_name, str)]
     id_filter = [ds_id for ds_id in names_or_ids if not isinstance(ds_id, str)]
     for ds_id in all_ds:
-        if ds_id in id_filter or ds_id.name in str_filter:
+        if ds_id in id_filter or ds_id['name'] in str_filter:
             yield ds_id
 
 
@@ -276,11 +298,8 @@ class FakeReader(FileYAMLReader):
         be disabled by specifying `filter_datasets=False`.
 
         """
-        with mock.patch('satpy.readers.yaml_reader.recursive_dict_update') as rdu, \
-                mock.patch('satpy.readers.yaml_reader.open'), \
-                mock.patch('satpy.readers.yaml_reader.yaml.load'):
-            rdu.return_value = {'reader': {'name': name}, 'file_types': {}}
-            super(FakeReader, self).__init__(['fake.yaml'])
+        reader_config = {'reader': {'name': name, 'config_files': ['fake.yaml']}, 'file_types': {}}
+        super(FakeReader, self).__init__(reader_config)
 
         if start_time is None:
             start_time = datetime.utcnow()
@@ -329,7 +348,7 @@ class FakeReader(FileYAMLReader):
         dataset_ids = self.all_ids.keys()
         loaded_datasets = DatasetDict()
         for k in dataset_keys:
-            if k == 'ds9_fail_load':
+            if k['name'] == 'ds9_fail_load':
                 continue
             for ds in dataset_ids:
                 if ds == k:
@@ -355,3 +374,81 @@ class CustomScheduler(object):
             raise RuntimeError("Too many dask computations were scheduled: "
                                "{}".format(self.total_computes))
         return dask.get(dsk, keys, **kwargs)
+
+
+def make_fake_scene(content_dict, daskify=False, area=True,
+                    common_attrs=None):
+    """Create a fake Scene.
+
+    Create a fake Scene object from fake data.  Data are provided in
+    the ``content_dict`` argument.  In ``content_dict``, keys should be
+    strings or DataID, and values may be either numpy.ndarray
+    or xarray.DataArray, in either case with exactly two dimensions.
+    The function will convert each of the numpy.ndarray objects into
+    an xarray.DataArray and assign those as datasets to a Scene object.
+    A fake AreaDefinition will be assigned for each array, unless disabled
+    by passing ``area=False``.  When areas are automatically generated,
+    arrays with the same shape will get the same area.
+
+    This function is exclusively intended for testing purposes.
+
+    If regular ndarrays are passed and the keyword argument daskify is
+    True, DataArrays will be created as dask arrays.  If False (default),
+    regular DataArrays will be created.  When the user passes xarray.DataArray
+    objects then this flag has no effect.
+
+    Args:
+        content_dict (Mapping): Mapping where keys correspond to objects
+            accepted by ``Scene.__setitem__``, i.e. strings or DataID,
+            and values may be either ``numpy.ndarray`` or
+            ``xarray.DataArray``.
+        daskify (bool): optional, to use dask when converting
+            ``numpy.ndarray`` to ``xarray.DataArray`.  No effect when the
+            values in ``content_dict`` are already ``xarray.DataArray`.
+        area (bool or BaseDefinition): Can be ``True``, ``False``, or an
+            instance of ``pyresample.geometry.BaseDefinition`` such as
+            ``AreaDefinition`` or ``SwathDefinition``.  If ``True``, which is
+            the default, automatically generate areas.  If ``False``, values
+            will not have assigned areas.  If an instance of
+            ``pyresample.geometry.BaseDefinition``, those instances will be
+            used for all generated fake datasets.  Warning: Passing an area as
+            a string (``area="germ"``) is not supported.
+        common_attrs (Mapping): optional, additional attributes that will
+            be added to every dataset in the scene.
+
+    Returns:
+        Scene object with datasets corresponding to content_dict.
+    """
+    import pyresample
+    import satpy
+    import xarray as xr
+    if common_attrs is None:
+        common_attrs = {}
+    if daskify:
+        import dask.array
+    sc = satpy.Scene()
+    for (did, arr) in content_dict.items():
+        extra_attrs = common_attrs.copy()
+        if isinstance(area, pyresample.geometry.BaseDefinition):
+            extra_attrs["area"] = area
+        elif area:
+            extra_attrs["area"] = pyresample.create_area_def(
+                    "test-area",
+                    {"proj": "eqc", "lat_ts": 0, "lat_0": 0, "lon_0": 0,
+                     "x_0": 0, "y_0": 0, "ellps": "sphere", "units": "m",
+                     "no_defs": None, "type": "crs"},
+                    units="m",
+                    shape=arr.shape,
+                    resolution=1000,
+                    center=(0, 0))
+        if isinstance(arr, xr.DataArray):
+            sc[did] = arr.copy()  # don't change attributes of input
+            sc[did].attrs.update(extra_attrs)
+        else:
+            if daskify:
+                arr = dask.array.from_array(arr)
+            sc[did] = xr.DataArray(
+                    arr,
+                    dims=("y", "x"),
+                    attrs=extra_attrs)
+    return sc
