@@ -23,7 +23,7 @@ import unittest
 from unittest import mock
 from datetime import datetime
 import tempfile
-from satpy import DatasetID
+from satpy.tests.utils import make_dsq
 
 import numpy as np
 
@@ -71,14 +71,12 @@ class TestCFWriter(unittest.TestCase):
         scn['test-array'] = xr.DataArray([1, 2, 3],
                                          attrs=dict(start_time=start_time,
                                                     end_time=end_time,
-                                                    prerequisites=[DatasetID('hej')]))
+                                                    prerequisites=[make_dsq(name='hej')]))
         with TempFile() as filename:
             scn.save_datasets(filename=filename, writer='cf')
             with xr.open_dataset(filename) as f:
                 self.assertTrue(np.all(f['test-array'][:] == [1, 2, 3]))
-                expected_prereq = ("DatasetID(name='hej', wavelength=None, "
-                                   "resolution=None, polarization=None, "
-                                   "calibration=None, level=None, modifiers=())")
+                expected_prereq = ("DataQuery(name='hej')")
                 self.assertEqual(f['test-array'].attrs['prerequisites'],
                                  expected_prereq)
 
@@ -94,7 +92,7 @@ class TestCFWriter(unittest.TestCase):
             scn['test-array'] = xr.DataArray([1, 2, 3],
                                              attrs=dict(start_time=start_time,
                                                         end_time=end_time,
-                                                        prerequisites=[DatasetID('hej')]))
+                                                        prerequisites=[make_dsq(name='hej')]))
 
             comp = {'zlib': True, 'complevel': 9}
             scn.save_datasets(filename='bla', writer='cf', compression=comp)
@@ -123,7 +121,7 @@ class TestCFWriter(unittest.TestCase):
                                          coords=coords,
                                          attrs=dict(start_time=start_time,
                                                     end_time=end_time,
-                                                    prerequisites=[DatasetID('hej')]))
+                                                    prerequisites=[make_dsq(name='hej')]))
         with TempFile() as filename:
             scn.save_datasets(filename=filename, writer='cf')
             with xr.open_dataset(filename) as f:
@@ -133,9 +131,7 @@ class TestCFWriter(unittest.TestCase):
                 self.assertNotIn('crs', f)
                 self.assertNotIn('_FillValue', f['x'].attrs)
                 self.assertNotIn('_FillValue', f['y'].attrs)
-                expected_prereq = ("DatasetID(name='hej', wavelength=None, "
-                                   "resolution=None, polarization=None, "
-                                   "calibration=None, level=None, modifiers=())")
+                expected_prereq = ("DataQuery(name='hej')")
                 self.assertEqual(f['test-array'].attrs['prerequisites'],
                                  expected_prereq)
 
@@ -502,11 +498,11 @@ class TestCFWriter(unittest.TestCase):
         # Create set of test attributes
         attrs, attrs_expected, attrs_expected_flat = self.get_test_attrs()
         attrs['area'] = 'some_area'
-        attrs['prerequisites'] = [DatasetID('hej')]
+        attrs['prerequisites'] = [make_dsq(name='hej')]
+        attrs['_satpy_id_name'] = 'myname'
 
         # Adjust expected attributes
-        expected_prereq = ("DatasetID(name='hej', wavelength=None, resolution=None, polarization=None, "
-                           "calibration=None, level=None, modifiers=())")
+        expected_prereq = ("DataQuery(name='hej')")
         update = {'prerequisites': [expected_prereq], 'long_name': attrs['name']}
 
         attrs_expected.update(update)
@@ -928,12 +924,10 @@ class TestCFWriter(unittest.TestCase):
         self.assertEqual(set(res.coords), {'longitude', 'latitude'})
         lat = res['latitude']
         lon = res['longitude']
-        self.assertTrue(np.all(lat.data == lats_ref))
-        self.assertTrue(np.all(lon.data == lons_ref))
-        self.assertDictContainsSubset({'name': 'latitude', 'standard_name': 'latitude', 'units': 'degrees_north'},
-                                      lat.attrs)
-        self.assertDictContainsSubset({'name': 'longitude', 'standard_name': 'longitude', 'units': 'degrees_east'},
-                                      lon.attrs)
+        np.testing.assert_array_equal(lat.data, lats_ref)
+        np.testing.assert_array_equal(lon.data, lons_ref)
+        assert {'name': 'latitude', 'standard_name': 'latitude', 'units': 'degrees_north'}.items() <= lat.attrs.items()
+        assert {'name': 'longitude', 'standard_name': 'longitude', 'units': 'degrees_east'}.items() <= lon.attrs.items()
 
         area = pyresample.geometry.AreaDefinition(
             'seviri',
@@ -953,21 +947,194 @@ class TestCFWriter(unittest.TestCase):
         self.assertEqual(set(res.coords), {'longitude', 'latitude'})
         lat = res['latitude']
         lon = res['longitude']
-        self.assertTrue(np.all(lat.data == lats_ref))
-        self.assertTrue(np.all(lon.data == lons_ref))
-        self.assertDictContainsSubset({'name': 'latitude', 'standard_name': 'latitude', 'units': 'degrees_north'},
-                                      lat.attrs)
-        self.assertDictContainsSubset({'name': 'longitude', 'standard_name': 'longitude', 'units': 'degrees_east'},
-                                      lon.attrs)
+        np.testing.assert_array_equal(lat.data, lats_ref)
+        np.testing.assert_array_equal(lon.data, lons_ref)
+        assert {'name': 'latitude', 'standard_name': 'latitude', 'units': 'degrees_north'}.items() <= lat.attrs.items()
+        assert {'name': 'longitude', 'standard_name': 'longitude', 'units': 'degrees_east'}.items() <= lon.attrs.items()
+
+    def test_load_module_with_old_pyproj(self):
+        """Test that cf_writer can still be loaded with pyproj 1.9.6."""
+        import pyproj # noqa 401
+        import sys
+        import importlib
+        old_version = sys.modules['pyproj'].__version__
+        sys.modules['pyproj'].__version__ = "1.9.6"
+        try:
+            importlib.reload(sys.modules['satpy.writers.cf_writer'])
+        finally:
+            # Tear down
+            sys.modules['pyproj'].__version__ = old_version
+            importlib.reload(sys.modules['satpy.writers.cf_writer'])
+
+    def test_global_attr_default_history_and_Conventions(self):
+        """Test saving global attributes history and Conventions"""
+        from satpy import Scene
+        import xarray as xr
+        scn = Scene()
+        start_time = datetime(2018, 5, 30, 10, 0)
+        end_time = datetime(2018, 5, 30, 10, 15)
+        scn['test-array'] = xr.DataArray([[1, 2, 3]],
+                                         dims=('y', 'x'),
+                                         attrs=dict(start_time=start_time,
+                                                    end_time=end_time,
+                                                    prerequisites=[make_dsq(name='hej')]))
+        with TempFile() as filename:
+            scn.save_datasets(filename=filename, writer='cf')
+            with xr.open_dataset(filename) as f:
+                self.assertEqual(f.attrs['Conventions'], 'CF-1.7')
+                self.assertIn('Created by pytroll/satpy on', f.attrs['history'])
+
+    def test_global_attr_history_and_Conventions(self):
+        """Test saving global attributes history and Conventions"""
+        from satpy import Scene
+        import xarray as xr
+        scn = Scene()
+        start_time = datetime(2018, 5, 30, 10, 0)
+        end_time = datetime(2018, 5, 30, 10, 15)
+        scn['test-array'] = xr.DataArray([[1, 2, 3]],
+                                         dims=('y', 'x'),
+                                         attrs=dict(start_time=start_time,
+                                                    end_time=end_time,
+                                                    prerequisites=[make_dsq(name='hej')]))
+        header_attrs = {}
+        header_attrs['history'] = 'TEST add history',
+        header_attrs['Conventions'] = 'CF-1.7, ACDD-1.3'
+        with TempFile() as filename:
+            scn.save_datasets(filename=filename, writer='cf', header_attrs=header_attrs)
+            with xr.open_dataset(filename) as f:
+                self.assertEqual(f.attrs['Conventions'], 'CF-1.7, ACDD-1.3')
+                self.assertIn('TEST add history\n', f.attrs['history'])
+                self.assertIn('Created by pytroll/satpy on', f.attrs['history'])
 
 
-def suite():
-    """Test suite for this writer's tests."""
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestCFWriter))
-    return mysuite
+class TestCFWriterData(unittest.TestCase):
+    """Test case for CF writer where data arrays are needed."""
+
+    def setUp(self):
+        """Create some testdata."""
+        import xarray as xr
+        import pyresample.geometry
+        data = [[75, 2], [3, 4]]
+        y = [1, 2]
+        x = [1, 2]
+        geos = pyresample.geometry.AreaDefinition(
+            area_id='geos',
+            description='geos',
+            proj_id='geos',
+            projection={'proj': 'geos', 'h': 35785831., 'a': 6378169., 'b': 6356583.8},
+            width=2, height=2,
+            area_extent=[-1, -1, 1, 1])
+        self.datasets = {'var1': xr.DataArray(data=data,
+                                              dims=('y', 'x'),
+                                              coords={'y': y, 'x': x}),
+                         'var2': xr.DataArray(data=data,
+                                              dims=('y', 'x'),
+                                              coords={'y': y, 'x': x}),
+                         'lat': xr.DataArray(data=data,
+                                             dims=('y', 'x'),
+                                             coords={'y': y, 'x': x}),
+                         'lon': xr.DataArray(data=data,
+                                             dims=('y', 'x'),
+                                             coords={'y': y, 'x': x})}
+        self.datasets['lat'].attrs['standard_name'] = 'latitude'
+        self.datasets['var1'].attrs['standard_name'] = 'dummy'
+        self.datasets['var2'].attrs['standard_name'] = 'dummy'
+        self.datasets['var2'].attrs['area'] = geos
+        self.datasets['var1'].attrs['area'] = geos
+        self.datasets['lat'].attrs['name'] = 'lat'
+        self.datasets['var1'].attrs['name'] = 'var1'
+        self.datasets['var2'].attrs['name'] = 'var2'
+        self.datasets['lon'].attrs['name'] = 'lon'
+
+    def test_dataset_is_projection_coords(self):
+        """Test the dataset_is_projection_coords function."""
+        from satpy.writers.cf_writer import dataset_is_projection_coords
+        self.assertTrue(dataset_is_projection_coords(self.datasets['lat']))
+        self.assertFalse(dataset_is_projection_coords(self.datasets['var1']))
+
+    def test_has_projection_coords(self):
+        """Test the has_projection_coords function."""
+        from satpy.writers.cf_writer import has_projection_coords
+        self.assertTrue(has_projection_coords(self.datasets))
+        self.datasets['lat'].attrs['standard_name'] = 'dummy'
+        self.assertFalse(has_projection_coords(self.datasets))
+
+    @mock.patch('satpy.writers.cf_writer.CFWriter.__init__', return_value=None)
+    def test_collect_datasets_with_latitude_named_lat(self, *mocks):
+        """Test collecting CF datasets with latitude named lat."""
+        from satpy.writers.cf_writer import CFWriter
+        from operator import getitem
+        self.datasets_list = [self.datasets[key] for key in self.datasets]
+        self.datasets_list_no_latlon = [self.datasets[key] for key in ['var1', 'var2']]
+
+        # Collect datasets
+        writer = CFWriter()
+        datas, start_times, end_times = writer._collect_datasets(self.datasets_list, include_lonlats=True)
+        datas2, start_times, end_times = writer._collect_datasets(self.datasets_list_no_latlon, include_lonlats=True)
+        # Test results
+
+        self.assertEqual(len(datas), 5)
+        self.assertEqual(set(datas.keys()), {'var1', 'var2', 'lon', 'lat', 'geos'})
+        self.assertRaises(KeyError, getitem, datas['var1'], 'latitude')
+        self.assertRaises(KeyError, getitem, datas['var1'], 'longitude')
+        self.assertEqual(datas2['var1']['latitude'].attrs['name'], 'latitude')
+        self.assertEqual(datas2['var1']['longitude'].attrs['name'], 'longitude')
 
 
-if __name__ == "__main__":
-    unittest.main()
+class EncodingUpdateTest(unittest.TestCase):
+    """Test update of netCDF encoding."""
+    def setUp(self):
+        import xarray as xr
+        self.ds = xr.Dataset({'foo': (('y', 'x'), [[1, 2], [3, 4]]),
+                              'bar': (('y', 'x'), [[3, 4], [5, 6]])},
+                             coords={'y': [1, 2],
+                                     'x': [3, 4],
+                                     'lon': (('y', 'x'), [[7, 8], [9, 10]])})
+
+    def test_without_time(self):
+        from satpy.writers.cf_writer import update_encoding
+
+        # Without time dimension
+        ds = self.ds.chunk(2)
+        kwargs = {'encoding': {'bar': {'chunksizes': (1, 1)}},
+                  'other': 'kwargs'}
+        enc, other_kwargs = update_encoding(ds, kwargs)
+        self.assertDictEqual(enc, {'y': {'_FillValue': None},
+                                   'x': {'_FillValue': None},
+                                   'lon': {'chunksizes': (2, 2)},
+                                   'foo': {'chunksizes': (2, 2)},
+                                   'bar': {'chunksizes': (1, 1)}})
+        self.assertDictEqual(other_kwargs, {'other': 'kwargs'})
+
+        # Chunksize may not exceed shape
+        ds = self.ds.chunk(8)
+        kwargs = {'encoding': {}, 'other': 'kwargs'}
+        enc, other_kwargs = update_encoding(ds, kwargs)
+        self.assertDictEqual(enc, {'y': {'_FillValue': None},
+                                   'x': {'_FillValue': None},
+                                   'lon': {'chunksizes': (2, 2)},
+                                   'foo': {'chunksizes': (2, 2)},
+                                   'bar': {'chunksizes': (2, 2)}})
+
+    def test_with_time(self):
+        from satpy.writers.cf_writer import update_encoding
+
+        # With time dimension
+        ds = self.ds.chunk(8).expand_dims({'time': [datetime(2009, 7, 1, 12, 15)]})
+        kwargs = {'encoding': {'bar': {'chunksizes': (1, 1, 1)}},
+                  'other': 'kwargs'}
+        enc, other_kwargs = update_encoding(ds, kwargs)
+        self.assertDictEqual(enc, {'y': {'_FillValue': None},
+                                   'x': {'_FillValue': None},
+                                   'lon': {'chunksizes': (2, 2)},
+                                   'foo': {'chunksizes': (1, 2, 2)},
+                                   'bar': {'chunksizes': (1, 1, 1)},
+                                   'time': {'_FillValue': None,
+                                            'calendar': 'proleptic_gregorian',
+                                            'units': 'days since 2009-07-01 12:15:00'},
+                                   'time_bnds': {'_FillValue': None,
+                                                 'calendar': 'proleptic_gregorian',
+                                                 'units': 'days since 2009-07-01 12:15:00'}})
+
+        # User-defined encoding may not be altered
+        self.assertDictEqual(kwargs['encoding'], {'bar': {'chunksizes': (1, 1, 1)}})
