@@ -99,6 +99,7 @@ This is what the corresponding ``ncdump`` output would look like in this case:
 """
 
 from collections import OrderedDict, defaultdict
+import copy
 import logging
 from datetime import datetime
 import json
@@ -114,10 +115,6 @@ from satpy.writers import Writer
 from satpy.writers.utils import flatten_dict
 
 from distutils.version import LooseVersion
-import pyproj
-if LooseVersion(pyproj.__version__) < LooseVersion('2.4.1'):
-    # technically 2.2, but important bug fixes in 2.4.1
-    raise ImportError("'cf' writer requires pyproj 2.4.1 or greater")
 
 
 logger = logging.getLogger(__name__)
@@ -147,6 +144,10 @@ CF_VERSION = 'CF-1.7'
 
 def create_grid_mapping(area):
     """Create the grid mapping instance for `area`."""
+    import pyproj
+    if LooseVersion(pyproj.__version__) < LooseVersion('2.4.1'):
+        # technically 2.2, but important bug fixes in 2.4.1
+        raise ImportError("'cf' writer requires pyproj 2.4.1 or greater")
     # let pyproj do the heavily lifting
     # pyproj 2.0+ required
     grid_mapping = area.crs.to_cf()
@@ -192,10 +193,10 @@ def area2gridmapping(dataarray):
     return dataarray, xr.DataArray(0, attrs=attrs, name=gmapping_var_name)
 
 
-def area2cf(dataarray, strict=False):
+def area2cf(dataarray, strict=False, got_lonlats=False):
     """Convert an area to at CF grid mapping or lon and lats."""
     res = []
-    if isinstance(dataarray.attrs['area'], SwathDefinition) or strict:
+    if not got_lonlats and (isinstance(dataarray.attrs['area'], SwathDefinition) or strict):
         dataarray = area2lonlat(dataarray)
     if isinstance(dataarray.attrs['area'], AreaDefinition):
         dataarray, gmapping = area2gridmapping(dataarray)
@@ -257,6 +258,21 @@ def link_coords(datas):
         dataset.attrs.pop('coordinates', None)
 
 
+def dataset_is_projection_coords(dataset):
+    """Check if dataset is a projection coords."""
+    if 'standard_name' in dataset.attrs and dataset.attrs['standard_name'] in ['longitude', 'latitude']:
+        return True
+    return False
+
+
+def has_projection_coords(ds_collection):
+    """Check if collection has a projection coords among data arrays."""
+    for dataset in ds_collection.values():
+        if dataset_is_projection_coords(dataset):
+            return True
+    return False
+
+
 def make_alt_coords_unique(datas, pretty=False):
     """Make non-dimensional coordinates unique among all datasets.
 
@@ -281,7 +297,7 @@ def make_alt_coords_unique(datas, pretty=False):
     tokens = defaultdict(set)
     for dataset in datas.values():
         for coord_name in dataset.coords:
-            if coord_name.lower() not in ('latitude', 'longitude', 'lat', 'lon') and coord_name not in dataset.dims:
+            if not dataset_is_projection_coords(dataset[coord_name]) and coord_name not in dataset.dims:
                 tokens[coord_name].add(tokenize(dataset[coord_name].data))
     coords_unique = dict([(coord_name, len(tokens) == 1) for coord_name, tokens in tokens.items()])
 
@@ -398,6 +414,73 @@ def encode_attrs_nc(attrs):
     return OrderedDict(encoded_attrs)
 
 
+def _set_default_chunks(encoding, dataset):
+    """Update encoding to preserve current dask chunks.
+
+    Existing user-defined chunks take precedence.
+    """
+    for var_name, variable in dataset.variables.items():
+        if variable.chunks:
+            chunks = tuple(
+                np.stack([variable.data.chunksize,
+                          variable.shape]).min(axis=0)
+            )  # Chunksize may not exceed shape
+            encoding.setdefault(var_name, {})
+            encoding[var_name].setdefault('chunksizes', chunks)
+
+
+def _set_default_fill_value(encoding, dataset):
+    """Set default fill values.
+
+    Avoid _FillValue attribute being added to coordinate variables
+    (https://github.com/pydata/xarray/issues/1865).
+    """
+    coord_vars = []
+    for data_array in dataset.values():
+        coord_vars.extend(set(data_array.dims).intersection(data_array.coords))
+    for coord_var in coord_vars:
+        encoding.setdefault(coord_var, {})
+        encoding[coord_var].update({'_FillValue': None})
+
+
+def _set_default_time_encoding(encoding, dataset):
+    """Set default time encoding.
+
+    Make sure time coordinates and bounds have the same units. Default is xarray's CF datetime
+    encoding, which can be overridden by user-defined encoding.
+    """
+    if 'time' in dataset:
+        try:
+            dtnp64 = dataset['time'].data[0]
+        except IndexError:
+            dtnp64 = dataset['time'].data
+
+        default = CFDatetimeCoder().encode(xr.DataArray(dtnp64))
+        time_enc = {'units': default.attrs['units'], 'calendar': default.attrs['calendar']}
+        time_enc.update(encoding.get('time', {}))
+        bounds_enc = {'units': time_enc['units'],
+                      'calendar': time_enc['calendar'],
+                      '_FillValue': None}
+        encoding['time'] = time_enc
+        encoding['time_bnds'] = bounds_enc  # FUTURE: Not required anymore with xarray-0.14+
+
+
+def update_encoding(dataset, to_netcdf_kwargs):
+    """Update encoding.
+
+    Preserve dask chunks, avoid fill values in coordinate variables and make sure that
+    time & time bounds have the same units.
+    """
+    other_to_netcdf_kwargs = to_netcdf_kwargs.copy()
+    encoding = other_to_netcdf_kwargs.pop('encoding', {}).copy()
+
+    _set_default_chunks(encoding, dataset)
+    _set_default_fill_value(encoding, dataset)
+    _set_default_time_encoding(encoding, dataset)
+
+    return encoding, other_to_netcdf_kwargs
+
+
 class CFWriter(Writer):
     """Writer producing NetCDF/CF compatible datasets."""
 
@@ -424,6 +507,11 @@ class CFWriter(Writer):
             name = new_data.attrs.pop('name')
             new_data = new_data.rename(name)
 
+        # Remove _satpy* attributes
+        satpy_attrs = [key for key in new_data.attrs if key.startswith('_satpy')]
+        for satpy_attr in satpy_attrs:
+            new_data.attrs.pop(satpy_attr)
+
         # Remove area as well as user-defined attributes
         for key in ['area'] + exclude_attrs:
             new_data.attrs.pop(key, None)
@@ -459,7 +547,7 @@ class CFWriter(Writer):
             new_data['y'].attrs['units'] = 'm'
 
         if 'crs' in new_data.coords:
-            new_data = new_data.drop('crs')
+            new_data = new_data.drop_vars('crs')
 
         if 'long_name' not in new_data.attrs and 'standard_name' not in new_data.attrs:
             new_data.attrs['long_name'] = new_data.name
@@ -475,6 +563,13 @@ class CFWriter(Writer):
 
         return new_data
 
+    @staticmethod
+    def update_encoding(dataset, to_netcdf_kwargs):
+        warnings.warn('CFWriter.update_encoding is deprecated. '
+                      'Use satpy.writers.cf_writer.update_encoding instead.',
+                      DeprecationWarning)
+        return update_encoding(dataset, to_netcdf_kwargs)
+
     def save_dataset(self, dataset, filename=None, fill_value=None, **kwargs):
         """Save the *dataset* to a given *filename*."""
         return self.save_datasets([dataset], filename, **kwargs)
@@ -485,7 +580,7 @@ class CFWriter(Writer):
         ds_collection = {}
         for ds in datasets:
             ds_collection.update(get_extra_ds(ds))
-
+        got_lonlats = has_projection_coords(ds_collection)
         datas = {}
         start_times = []
         end_times = []
@@ -497,7 +592,7 @@ class CFWriter(Writer):
             # structure of attributes
             ds = ds.copy(deep=True)
             try:
-                new_datasets = area2cf(ds, strict=include_lonlats)
+                new_datasets = area2cf(ds, strict=include_lonlats, got_lonlats=got_lonlats)
             except KeyError:
                 new_datasets = [ds]
             for new_ds in new_datasets:
@@ -514,39 +609,6 @@ class CFWriter(Writer):
 
         return datas, start_times, end_times
 
-    def update_encoding(self, dataset, to_netcdf_kwargs):
-        """Update encoding.
-
-        Avoid _FillValue attribute being added to coordinate variables (https://github.com/pydata/xarray/issues/1865).
-        """
-        other_to_netcdf_kwargs = to_netcdf_kwargs.copy()
-        encoding = other_to_netcdf_kwargs.pop('encoding', {}).copy()
-        coord_vars = []
-        for data_array in dataset.values():
-            coord_vars.extend(set(data_array.dims).intersection(data_array.coords))
-        for coord_var in coord_vars:
-            encoding.setdefault(coord_var, {})
-            encoding[coord_var].update({'_FillValue': None})
-
-        # Make sure time coordinates and bounds have the same units. Default is xarray's CF datetime
-        # encoding, which can be overridden by user-defined encoding.
-        if 'time' in dataset:
-            try:
-                dtnp64 = dataset['time'].data[0]
-            except IndexError:
-                dtnp64 = dataset['time'].data
-
-            default = CFDatetimeCoder().encode(xr.DataArray(dtnp64))
-            time_enc = {'units': default.attrs['units'], 'calendar': default.attrs['calendar']}
-            time_enc.update(encoding.get('time', {}))
-            bounds_enc = {'units': time_enc['units'],
-                          'calendar': time_enc['calendar'],
-                          '_FillValue': None}
-            encoding['time'] = time_enc
-            encoding['time_bnds'] = bounds_enc  # FUTURE: Not required anymore with xarray-0.14+
-
-        return encoding, other_to_netcdf_kwargs
-
     def save_datasets(self, datasets, filename=None, groups=None, header_attrs=None, engine=None, epoch=EPOCH,
                       flatten_attrs=False, exclude_attrs=None, include_lonlats=True, pretty=False,
                       compression=None, **to_netcdf_kwargs):
@@ -610,12 +672,21 @@ class CFWriter(Writer):
             if flatten_attrs:
                 header_attrs = flatten_dict(header_attrs)
             root.attrs = encode_attrs_nc(header_attrs)
-        root.attrs['history'] = 'Created by pytroll/satpy on {}'.format(datetime.utcnow())
+        _history_create = 'Created by pytroll/satpy on {}'.format(datetime.utcnow())
+        if 'history' in root.attrs:
+            if isinstance(root.attrs['history'], list):
+                root.attrs['history'] = ''.join(root.attrs['history'])
+            root.attrs['history'] += '\n' + _history_create
+        else:
+            root.attrs['history'] = _history_create
+
         if groups is None:
             # Groups are not CF-1.7 compliant
-            root.attrs['Conventions'] = CF_VERSION
+            if 'Conventions' not in root.attrs:
+                root.attrs['Conventions'] = CF_VERSION
 
         # Remove satpy-specific kwargs
+        to_netcdf_kwargs = copy.deepcopy(to_netcdf_kwargs)  # may contain dictionaries (encoding)
         satpy_kwargs = ['overlay', 'decorate', 'config_files']
         for kwarg in satpy_kwargs:
             to_netcdf_kwargs.pop(kwarg, None)
@@ -641,7 +712,7 @@ class CFWriter(Writer):
                 grp_str = ' of group {}'.format(group_name) if group_name is not None else ''
                 logger.warning('No time dimension in datasets{}, skipping time bounds creation.'.format(grp_str))
 
-            encoding, other_to_netcdf_kwargs = self.update_encoding(dataset, to_netcdf_kwargs)
+            encoding, other_to_netcdf_kwargs = update_encoding(dataset, to_netcdf_kwargs)
             res = dataset.to_netcdf(filename, engine=engine, group=group_name, mode='a', encoding=encoding,
                                     **other_to_netcdf_kwargs)
             written.append(res)
